@@ -3116,5 +3116,10 @@ def submit(port, host='127.0.0.1',  db=0):
 		r.hset('dict:word_level', w, 'awl')
 	print(">> finished loading awl")
 
-if __name__ == '__main__':
-	submit(6311)
+def save():
+	import json
+	with open('word_awl.json','w') as fw: 
+		fw.write(json.dumps([ w for w in word_awl]))
+
+if __name__ == '__main__': 
+	save()
\ No newline at end of file
