@@ -37,8 +37,9 @@ def dims_score(dims:dict={"doc_tc": 191.0, "asl": 74.6154, "ttr2": 62.2009, "ttr
 	score = sum([ v['score'] * v['coef'] for name, v in dim_scores.items()])
 	ratio = sum([ v['coef'] for name, v in dim_scores.items()])
 	
-	return {"formula_score": score/ratio, 
-	'cate_score': ( si:=Counter(), [ si.update( {ar['cate'] : ar['score'] * ar['cate-coef']})  for ar in dim_scores.values()] )[0] } #'cate_score_default'
+	si = Counter()
+	[ si.update( {ar['cate'] : ar['score'] * ar['cate-coef']})  for ar in dim_scores.values()] #'cate_score_default'
+	return {"formula_score": score/ratio, 'cate_score': si}
 
 if __name__ == '__main__':
 	res = dims_score()
