@@ -33,6 +33,39 @@ def index_doc(did, doc):
 from so import * 
 cursor_sql = lambda query, cursor: requests.post(f"http://{requests.eshost}:{requests.esport}/_sql", json={"query":query, "cursor":cursor}).json() #  move to so/__init__ later
 
+def sqlsi(query): #select lex, count(*)
+	si = Counter()
+	cursor=''
+	while True : 
+		res = cursor_sql(query, cursor)  
+		si.update( dict(res['rows']) )
+		cursor = res.get('cursor','') 
+		if not cursor: break
+	return si #dict(si.most_common())
+
+def sqlssi(query="select lem, lex, count(*) cnt from gzjc where type = 'tok' and lem rlike '[a-z]+' group by lem, lex"
+		, iftrue = lambda s1, s2: s1 and s2
+		, s1_func = lambda s: s
+		, s2_func = lambda s: s  # lower()
+		): 
+	ssi = defaultdict(Counter)
+	cursor=''
+	while True : 
+		res = cursor_sql(query, cursor) 
+		[ ssi[ s1_func(s1) ].update({ s2_func(s2) :cnt}) for s1, s2, cnt in res['rows'] if iftrue(s1, s2) ] 
+		cursor = res.get('cursor','') 
+		if not cursor: break
+	return ssi 
+
+trpssi	= lambda idxname, dep='dobj', gpos='VERB', dpos='NOUN': sqlssi(f"select gov, lem, count(*) cnt from {idxname} where type = 'tok' and pos = '{dpos}' and dep ='{dep}' and lem rlike '[a-z]+' and gov like '%_{gpos}' group by gov, lem", s1_func =lambda s: s.split('_')[0])
+_trpssi = lambda idxname, dep='dobj', gpos='VERB', dpos='NOUN': sqlssi(f"select lem, gov, count(*) cnt from {idxname} where type = 'tok' and pos = '{dpos}' and dep ='{dep}' and lem rlike '[a-z]+' and gov like '%_{gpos}' group by lem, gov", s2_func =lambda s: s.split('_')[0])
+
+def save_ssi(idxname, suffix, ssi, dic): 
+	with open(f"{idxname}.{suffix}", 'w') as fw: 
+		start = time.time()
+		fw.write( json.dumps( dict({ k: dict(v.most_common()) for k,v in ssi.items()}, **dic ) ) + "\n") 
+		print( f"saved: {idxname}.{suffix}, \t using: ", time.time() - start, flush=True)
+
 class ES(object):
 	def __init__(self, eshost='127.0.0.1',esport=9200): 
 		self.host = eshost # to be removed later 
@@ -157,62 +190,41 @@ class ES(object):
 			del doc["_score"]
 			print (json.dumps(doc))  
 
-	def sql(self, query="select lem, count(*) cnt from dic where type = 'tok' and pos ='VERB' and lem rlike '[a-z]+' group by lem"): 
-		''' python -m so sql "select lem, count(*) cnt from gzjc where type = 'tok' and pos ='VERB' and lem rlike '[a-z]+' group by lem"  > gzjc.esjson '''
-		cursor=''
-		while True : 
-			res = requests.post(f"http://{self.host}:{self.port}/_sql", json={"query":query, "cursor":cursor}).json()
-			print (json.dumps(res['rows']))
-			cursor = res.get('cursor','') 
-			if not cursor: break			
+	def tocos(self, idxname): 
+		''' submit to cos , 2022.6.29 '''
+		dic = {"_sntsum": sntnum(idxname), "_lexsum": lexsum(idxname) }
+		print ("started:", idxname, "\t", dic, flush=True) 
 
-	def lemcnt(self, idxname, pos='LEX'): 
-		''' python -m so lemcnt dic --pos VERB , 2022.6.23 '''
-		si = Counter()
-		query=f"select lex, count(*) cnt from {idxname} where type = 'tok' and lex rlike '[a-zA-Z]+' group by lex" if pos == 'LEX' else f"select lem, count(*) cnt from {idxname} where type = 'tok' and lem rlike '[a-z]+' group by lem" if pos == 'LEM' else f"select lem, count(*) cnt from {idxname} where type = 'tok' and pos ='{pos}' and lem rlike '[a-z]+' group by lem"
-		cursor=''
-		while True : 
-			res = cursor_sql(query, cursor)  # res = requests.post(f"http://{self.host}:{self.port}/_sql", json={"query":query, "cursor":cursor}).json()
-			si.update( dict(res['rows']) )
-			cursor = res.get('cursor','') 
-			if not cursor: break
-		print ( json.dumps( dict({k:v for k,v in si.most_common()}, **{"_sntnum": sntnum(idxname), "_sum": sum([v for k,v in si.items()])} ) ) ) 
+		poslemcnt = sqlssi(f"select pos, lem, count(*) cnt from {idxname} where type = 'tok' and lem rlike '[a-z]+' group by pos, lem", iftrue=lambda pos, lem: pos not in ('NNP','PUNCT','X') )
+		poslemcnt['LEX'] = sqlsi(f"select lex, count(*) cnt from {idxname} where type = 'tok' and lex rlike '[a-zA-Z]+' group by lex")
+		poslemcnt['LEM'] = sqlsi(f"select lem, count(*) cnt from {idxname} where type = 'tok' and lem rlike '[a-z]+' group by lem")
+		save_ssi(idxname, 'poslemcnt', poslemcnt, dic) 
 
-	def trpcnt(self, idxname, dep='dobj', gpos='VERB', dpos='NOUN', inverse:bool=False): 
-		''' python -m so trpcnt dic --dep dobj , 2022.6.23 '''
-		ssi = defaultdict(Counter)
-		query=f"select gov, lem, count(*) cnt from {idxname} where type = 'tok' and pos = '{dpos}' and dep ='{dep}' and lem rlike '[a-z]+' and gov like '%_{gpos}' group by gov, lem"
-		cursor=''
-		while True : 
-			res = cursor_sql(query, cursor) 
-			[ ssi[ lem ].update({gov.split('_')[0]:cnt}) for gov, lem, cnt in res['rows'] ] if inverse else [ ssi[gov.split('_')[0] ].update({lem:cnt}) for gov, lem, cnt in res['rows'] ]
-			cursor = res.get('cursor','') 
-			if not cursor: break
-		print ( json.dumps( dict({ k: dict(v.most_common()) for k,v in ssi.items()}, **{"_sntnum": sntnum(idxname) } ) ) ) 
+		save_ssi(idxname, "lemlexcnt", sqlssi(f"select lem, lex, count(*) cnt from {idxname} where type = 'tok' and lem rlike '[a-z]+' group by lem, lex", iftrue=lambda pos, lem: pos not in ('NNP','PUNCT','X') , s2_func = lambda s: s.lower() ), dic)  
+		save_ssi(idxname, "lemposcnt", sqlssi(f"select lem, pos, count(*) cnt from {idxname} where type = 'tok' and lem rlike '[a-z]+' group by lem, pos", iftrue=lambda pos, lem: pos not in ('NNP','PUNCT','X') ),  dic) 
 
-	def poscnt(self, idxname): 
-		''' python -m so poscnt dic , 2022.6.23 '''
-		ssi = defaultdict(Counter)
-		query=f"select lem, pos, count(*) cnt from {idxname} where type = 'tok' and lem rlike '[a-z]+' group by lem, pos"
-		cursor=''
-		while True : 
-			res = cursor_sql(query, cursor) 
-			[ ssi[ lem ].update({pos:cnt}) for lem, pos, cnt in res['rows'] if pos not in ('NNP','X')] 
-			cursor = res.get('cursor','') 
-			if not cursor: break
-		print ( json.dumps( dict({ k: dict(v.most_common()) for k,v in ssi.items()}, **{"_sntnum": sntnum(idxname) } ) ) ) 
+		save_ssi(idxname, "dobj_VERB_NOUN",		trpssi(idxname, 'dobj', 'VERB', 'NOUN'), dic) 
+		save_ssi(idxname, "~dobj_VERB_NOUN",	_trpssi(idxname, 'dobj', 'VERB', 'NOUN'), dic) 
+		save_ssi(idxname, "nsubj_VERB_NOUN",	trpssi(idxname, 'nsubj', 'VERB', 'NOUN'), dic) 
+		save_ssi(idxname, "~nsubj_VERB_NOUN",	_trpssi(idxname, 'nsubj', 'VERB', 'NOUN'), dic) 
+		save_ssi(idxname, "amod_NOUN_ADJ",		trpssi(idxname, 'amod', 'NOUN', 'ADJ'), dic) 
+		save_ssi(idxname, "~amod_NOUN_ADJ",		_trpssi(idxname, 'amod', 'NOUN', 'ADJ'), dic) 
+		save_ssi(idxname, "advmod_VERB_ADV",	trpssi(idxname, 'advmod', 'VERB', 'ADV'), dic) 
+		save_ssi(idxname, "~advmod_VERB_ADV",	_trpssi(idxname, 'advmod', 'VERB', 'ADV'), dic) 
+		save_ssi(idxname, "advmod_ADJ_ADV",		trpssi(idxname, 'advmod', 'ADJ', 'ADV'), dic) 
+		save_ssi(idxname, "~advmod_ADJ_ADV",	_trpssi(idxname, 'advmod', 'ADJ', 'ADV'), dic) 
 
-	def ssi(self, query="select lem, lex, count(*) cnt from gzjc where type = 'tok' and lem rlike '[a-z]+' group by lem, lex"): 
-		''' python -m so ssi ...  > gzjc.lexcnt , 2022.6.27 '''
-		ssi = defaultdict(Counter)
-		cursor=''
-		while True : 
-			res = cursor_sql(query, cursor) 
-			[ ssi[ lem ].update({lex.lower():cnt}) for lem, lex, cnt in res['rows'] ] 
-			cursor = res.get('cursor','') 
-			if not cursor: break
-		idxname = query.split("where")[0].strip().split("from")[-1].strip()
-		print ( json.dumps( dict({ k: dict(v.most_common()) for k,v in ssi.items()}, **{"_sntnum": sntnum(idxname) } ) ) ) 
+		save_ssi(idxname, "meta", {
+			"wordlen":	sqlsi(f"select length(lex) wc, count(*) cnt from {idxname} where type = 'tok' group by wc"), 
+			"pos":		sqlsi(f"select pos, count(*) cnt from {idxname} where type = 'tok' group by pos"), 
+			"tag":		sqlsi(f"select tag, count(*) cnt from {idxname} where type = 'tok' group by tag"), 
+			"dep":		sqlsi(f"select dep, count(*) cnt from {idxname} where type = 'tok' group by dep"), 
+			"tc":		sqlsi(f"select tc, count(*) cnt from {idxname} where type = 'snt' group by tc"),
+			"stype":	sqlsi(f"select tag, count(*) cnt from {idxname} where type = 'stype' group by tag"),
+			"vpat":		sqlsi(f"select type, count(*) cnt from {idxname} where type like 's%' or type like 'v%' group by type"), # svo, vprt ,vtov
+			"cl":		sqlsi(f"select tag, count(*) cnt from {idxname} where type = 'cl' group by tag"),
+			"verbnet":	sqlsi(f"select chunk, count(*) cnt from {idxname} where type = 'verbnet' group by chunk")} ,  dic) 
+		print ('[tocos] totally finished:', idxname)
 
 	def load(self, infile, idxname=None, batch=100000, refresh:bool=True): 
 		''' python3 -m so load gzjc.esjson '''
@@ -234,4 +246,74 @@ class ES(object):
 		print(">>finished " , infile, idxname )
 
 if __name__ == '__main__':
-	fire.Fire(ES)
\ No newline at end of file
+	fire.Fire(ES)
+
+'''
+ubuntu@es-corpusly-com-105-249:/data/cikuu/pypi/so$ python __main__.py ssi  --query "select pos, lem, count(*) cnt from gzjc where type = 'tok' and lem rlike '[a-z]+' group by pos, lem" > gzjc.poslemcnt
+
+	def meta(self, idxname):
+		dic = {
+		"wordlen": sqlsi(f"select length(lex) wc, count(*) cnt from {idxname} where type = 'tok' group by wc"), 
+		"pos": sqlsi(f"select pos, count(*) cnt from {idxname} where type = 'tok' group by pos"), 
+		"tc": sqlsi(f"select tc, count(*) cnt from {idxname} where type = 'snt' group by tc"),
+		"stype":sqlsi(f"select tag, count(*) cnt from {idxname} where type = 'stype' group by tag"),
+		"cl": sqlsi(f"select tag, count(*) cnt from {idxname} where type = 'cl' group by tag"),
+		"verbnet": sqlsi(f"select chunk, count(*) cnt from {idxname} where type = 'verbnet' group by chunk"),
+		"_lexsum": lexsum(idxname),
+		"_sntsum": sntnum(idxname)	}
+		print( json.dumps(dic)) 
+
+	def ssi(self, query="select lem, lex, count(*) cnt from gzjc where type = 'tok' and lem rlike '[a-z]+' group by lem, lex"): 
+		ssi = defaultdict(Counter)
+		cursor=''
+		while True : 
+			res = cursor_sql(query, cursor) 
+			[ ssi[ lem ].update({lex.lower():cnt}) for lem, lex, cnt in res['rows'] ] 
+			cursor = res.get('cursor','') 
+			if not cursor: break
+		idxname = query.split("where")[0].strip().split("from")[-1].strip()
+		print ( json.dumps( dict({ k: dict(v.most_common()) for k,v in ssi.items()}, **{"_sntsum": sntnum(idxname) } ) ) ) 
+
+	def poscnt(self, idxname): 
+		ssi = defaultdict(Counter)
+		query=f"select lem, pos, count(*) cnt from {idxname} where type = 'tok' and lem rlike '[a-z]+' group by lem, pos"
+		cursor=''
+		while True : 
+			res = cursor_sql(query, cursor) 
+			[ ssi[ lem ].update({pos:cnt}) for lem, pos, cnt in res['rows'] if pos not in ('NNP','X')] 
+			cursor = res.get('cursor','') 
+			if not cursor: break
+		print ( json.dumps( dict({ k: dict(v.most_common()) for k,v in ssi.items()}, **{"_sntnum": sntnum(idxname) } ) ) ) 
+
+	def sql(self, query="select lem, count(*) cnt from dic where type = 'tok' and pos ='VERB' and lem rlike '[a-z]+' group by lem"): 
+		cursor=''
+		while True : 
+			res = requests.post(f"http://{self.host}:{self.port}/_sql", json={"query":query, "cursor":cursor}).json()
+			print (json.dumps(res['rows']))
+			cursor = res.get('cursor','') 
+			if not cursor: break			
+
+	def lemcnt(self, idxname, pos='LEX'): 
+		si = Counter()
+		query=f"select lex, count(*) cnt from {idxname} where type = 'tok' and lex rlike '[a-zA-Z]+' group by lex" if pos == 'LEX' else f"select lem, count(*) cnt from {idxname} where type = 'tok' and lem rlike '[a-z]+' group by lem" if pos == 'LEM' else f"select lem, count(*) cnt from {idxname} where type = 'tok' and pos ='{pos}' and lem rlike '[a-z]+' group by lem"
+		cursor=''
+		while True : 
+			res = cursor_sql(query, cursor)  # res = requests.post(f"http://{self.host}:{self.port}/_sql", json={"query":query, "cursor":cursor}).json()
+			si.update( dict(res['rows']) )
+			cursor = res.get('cursor','') 
+			if not cursor: break
+		print ( json.dumps( dict({k:v for k,v in si.most_common()}, **{"_sntnum": sntnum(idxname), "_sum": sum([v for k,v in si.items()])} ) ) ) 
+
+	def trpcnt(self, idxname, dep='dobj', gpos='VERB', dpos='NOUN', inverse:bool=False): 
+		ssi = defaultdict(Counter)
+		query=f"select gov, lem, count(*) cnt from {idxname} where type = 'tok' and pos = '{dpos}' and dep ='{dep}' and lem rlike '[a-z]+' and gov like '%_{gpos}' group by gov, lem"
+		cursor=''
+		while True : 
+			res = cursor_sql(query, cursor) 
+			[ ssi[ lem ].update({gov.split('_')[0]:cnt}) for gov, lem, cnt in res['rows'] ] if inverse else [ ssi[gov.split('_')[0] ].update({lem:cnt}) for gov, lem, cnt in res['rows'] ]
+			cursor = res.get('cursor','') 
+			if not cursor: break
+		print ( json.dumps( dict({ k: dict(v.most_common()) for k,v in ssi.items()}, **{"_sntnum": sntnum(idxname) } ) ) ) 
+
+
+'''
\ No newline at end of file
